@@ -17,10 +17,14 @@
 
 from argparse import Action
 
+from django.utils import six
+
 
 class GroupnameAction(Action):
     def __call__(self, parser, namespace, value, option_string):
         # NOTE: we do not get/create database, because --service might be given
         #   afterwards and then we'd get the group with no service.
-        groupname = value.lower().decode('utf-8')
+        groupname = value.lower()
+        if not six.PY3:
+            groupname = groupname.decode('utf-8')
         setattr(namespace, self.dest, groupname)
