@@ -15,10 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with RestAuth.  If not, see <http://www.gnu.org/licenses/>.
 
-try:
-    import httplib as httpclient  # python 2.x
-except ImportError:
-    from http import client as httpclient  # python 3.x
+from __future__ import unicode_literals
 
 from django.utils.unittest import skipUnless
 
@@ -28,6 +25,10 @@ from django.contrib.auth.hashers import load_hashers
 from django.contrib.auth.hashers import make_password
 from django.test import TestCase
 from django.test.utils import override_settings
+from django.utils import six
+
+# py2/py3 compat imports:
+from django.utils.six.moves import http_client
 
 from RestAuth.common.errors import PropertyNotFound
 from RestAuth.common.testdata import RestAuthTest
@@ -53,14 +54,14 @@ from RestAuth.common.testdata import username3
 class GetUsersTests(RestAuthTest):  # GET /users/
     def test_get_empty_users(self):
         resp = self.get('/users/')
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertItemsEqual(self.parse(resp, 'list'), [])
 
     def test_get_one_user(self):
         self.create_user(username1, password1)
 
         resp = self.get('/users/')
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertItemsEqual(self.parse(resp, 'list'), [username1])
 
     def test_get_two_users(self):
@@ -68,7 +69,7 @@ class GetUsersTests(RestAuthTest):  # GET /users/
         self.create_user(username2, password1)
 
         resp = self.get('/users/')
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertItemsEqual(self.parse(resp, 'list'), [username1, username2])
 
 
@@ -83,7 +84,7 @@ class AddUserTests(RestAuthTest):  # POST /users/
     def test_add_user(self):
         resp = self.post('/users/', {'user': username1, 'password': password1})
 
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertEqual(self.get_usernames(), [username1])
         self.assertPassword(username1, password1)
         user = user_backend.get(username1)
@@ -91,7 +92,7 @@ class AddUserTests(RestAuthTest):  # POST /users/
 
     def test_add_two_users(self):
         resp = self.post('/users/', {'user': username1, 'password': password1})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertEqual(self.get_usernames(), [username1])
         self.assertPassword(username1, password1)
         self.assertFalsePassword(username1, password2)
@@ -99,7 +100,7 @@ class AddUserTests(RestAuthTest):  # POST /users/
         self.assertProperties(user1, {})
 
         resp = self.post('/users/', {'user': username2, 'password': password2})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertEqual(self.get_usernames(), [username1, username2])
         user2 = user_backend.get(username2)
         self.assertProperties(user2, {})
@@ -112,7 +113,7 @@ class AddUserTests(RestAuthTest):  # POST /users/
     def test_add_user_twice(self):
         self.assertEqual(self.get_usernames(), [])
         resp = self.post('/users/', {'user': username1, 'password': password1})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertEqual(self.get_usernames(), [username1])
         user = user_backend.get(username1)
         self.assertProperties(user, {})
@@ -122,7 +123,7 @@ class AddUserTests(RestAuthTest):  # POST /users/
 
         # add again:
         resp = self.post('/users/', {'user': username1, 'password': password2})
-        self.assertEqual(resp.status_code, httpclient.CONFLICT)
+        self.assertEqual(resp.status_code, http_client.CONFLICT)
         self.assertEqual(self.get_usernames(), [username1])
 
         # check that we still have the old password and properties:
@@ -131,7 +132,7 @@ class AddUserTests(RestAuthTest):  # POST /users/
 
     def test_add_user_no_pass(self):
         resp = self.post('/users/', {'user': username1})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertEqual(self.get_usernames(), [username1])
         self.assertFalsePassword(username1, '')
         self.assertFalsePassword(username1, None)
@@ -140,7 +141,7 @@ class AddUserTests(RestAuthTest):  # POST /users/
         self.assertProperties(user_backend.get(username1), {})
 
         resp = self.post('/users/', {'user': username2, 'password': ''})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertEqual(self.get_usernames(), [username1, username2])
         user = user_backend.get(username2)
         self.assertFalsePassword(username2, '')
@@ -150,7 +151,7 @@ class AddUserTests(RestAuthTest):  # POST /users/
         self.assertProperties(user, {})
 
         resp = self.post('/users/', {'user': username3, 'password': None})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertItemsEqual(
             self.get_usernames(), [username1, username2, username3])
         user = user_backend.get(username3)
@@ -165,7 +166,7 @@ class AddUserTests(RestAuthTest):  # POST /users/
             propkey1: propval1
         }})
 
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertEqual(self.get_usernames(), [username1])
 
         user = user_backend.get(username1)
@@ -174,41 +175,41 @@ class AddUserTests(RestAuthTest):  # POST /users/
     def test_add_user_with_properties(self):
         props = {propkey1: propval1, propkey2: propval2}
         resp = self.post('/users/', {'user': username1, 'properties': props})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertProperties(user_backend.get(username1), props)
 
     def test_bad_requests(self):
         self.assertEqual(self.get_usernames(), [])
 
         resp = self.post('/users/', {'password': 'foobar'})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertEqual(self.get_usernames(), [])
 
         resp = self.post('/users/', {})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertEqual(self.get_usernames(), [])
 
         resp = self.post('/users/', {
             'userasdf': username1, 'passwordasdf': 'foobar'
         })
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertEqual(self.get_usernames(), [])
 
     def test_add_invalid_username(self):
         username = 'foo/bar'
         resp = self.post('/users/', {'user': username, 'password': password1})
-        self.assertEqual(resp.status_code, httpclient.PRECONDITION_FAILED)
+        self.assertEqual(resp.status_code, http_client.PRECONDITION_FAILED)
         self.assertEqual(self.get_usernames(), [])
 
         username = 'foo:bar'
         resp = self.post('/users/', {'user': username, 'password': password1})
-        self.assertEqual(resp.status_code, httpclient.PRECONDITION_FAILED)
+        self.assertEqual(resp.status_code, http_client.PRECONDITION_FAILED)
         self.assertEqual(self.get_usernames(), [])
 
     def test_add_user_with_long_username(self):
         username = 'abc' * 200
         resp = self.post('/users/', {'user': username})
-        self.assertEqual(resp.status_code, httpclient.PRECONDITION_FAILED)
+        self.assertEqual(resp.status_code, http_client.PRECONDITION_FAILED)
         self.assertEqual(self.get_usernames(), [])
 
 
@@ -224,71 +225,71 @@ class UserTests(RestAuthTest):
 class UserExistsTests(UserTests):  # GET /users/<user>/
     def test_user_exists(self):
         resp = self.get('/users/%s/' % username1)
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
 
         resp = self.get('/users/%s/' % username2)
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
 
         resp = self.get('/users/%s/' % username3)
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
 
 class VerifyPasswordsTest(UserTests):  # POST /users/<user>/
     def test_user_doesnt_exist(self):
         resp = self.post('/users/%s/' % username3, {'password': 'foobar'})
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
     def test_verify_password(self):
         resp = self.post('/users/%s/' % username1, {'password': password1})
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
 
         resp = self.post('/users/%s/' % username2, {'password': password2})
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
 
     def test_verify_wrong_password(self):
         resp = self.post('/users/%s/' % username1, {'password': 'wrong'})
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
         resp = self.post('/users/%s/' % username2, {'password': 'wrong'})
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
     def test_verify_disabled_password(self):
         user3 = self.create_user(username3, None)
 
         resp = self.post('/users/%s/' % username3, {'password': 'wrong'})
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
         resp = self.post('/users/%s/' % username3, {'password': ''})
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
         resp = self.post('/users/%s/' % username3, {'password': None})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
 
     def test_bad_requests(self):
         resp = self.post('/users/%s/' % username1, {})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
 
         resp = self.post('/users/%s/' % username1, {'foo': 'bar'})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
 
         resp = self.post('/users/%s/' % username1,
                          {'password': 'foobar', 'foo': 'bar'})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
 
 
 class ChangePasswordsTest(UserTests):  # PUT /users/<user>/
     def test_user_doesnt_exist(self):
         resp = self.put('/users/%s/' % username3, {'password': password3})
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
     def test_change_password(self):
         resp = self.put('/users/%s/' % username1, {'password': password3})
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
         self.assertFalsePassword(username1, password1)
         self.assertFalsePassword(username1, password2)
         self.assertPassword(username1, password3)
@@ -300,43 +301,43 @@ class ChangePasswordsTest(UserTests):  # PUT /users/<user>/
 
     def test_disable_password(self):
         resp = self.put('/users/%s/' % username1, {})
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
         self.assertFalsePassword(username1, password1)
         self.assertFalsePassword(username1, '')
         self.assertFalsePassword(username1, None)
 
         resp = self.put('/users/%s/' % username1, {'password': ''})
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
         self.assertFalsePassword(username1, password1)
         self.assertFalsePassword(username1, '')
         self.assertFalsePassword(username1, None)
 
         resp = self.put('/users/%s/' % username1, {'password': None})
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
         self.assertFalsePassword(username1, password1)
         self.assertFalsePassword(username1, '')
         self.assertFalsePassword(username1, None)
 
     def test_bad_requests(self):
         resp = self.put('/users/%s/' % username1, {'foo': password2})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertPassword(username1, password1)
 
         resp = self.put('/users/%s/' % username1,
                         {'password': password3, 'foo': 'bar'})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertPassword(username1, password1)
 
 
 class DeleteUserTest(UserTests):  # DELETE /users/<user>/
     def test_user_doesnt_exist(self):
         resp = self.delete('/users/%s/' % username3)
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
     def test_delete_user(self):
         resp = self.delete('/users/%s/' % username1)
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
         self.assertFalse(user_backend.exists(username1))
         self.assertTrue(user_backend.exists(username2))
 
@@ -366,27 +367,27 @@ class GetAllPropertiesTests(PropertyTests):  # GET /users/<user>/props/
 
     def test_user_doesnot_exist(self):
         resp = self.get('/users/%s/props/' % username3)
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
     def test_get_no_properties(self):
         resp = self.get('/users/%s/props/' % username1)
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertDictEqual(self.parse(resp, 'dict'), {})
 
         resp = self.get('/users/%s/props/' % username2)
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertDictEqual(self.parse(resp, 'dict'), {})
 
     def test_get_single_property(self):
         property_backend.create(user=self.user1, key=propkey1, value=propval1)
 
         resp = self.get('/users/%s/props/' % username1)
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertDictEqual(self.parse(resp, 'dict'), {propkey1: propval1})
 
         resp = self.get('/users/%s/props/' % username2)
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertDictEqual(self.parse(resp, 'dict'), {})
 
     def test_get_two_properties(self):
@@ -394,12 +395,12 @@ class GetAllPropertiesTests(PropertyTests):  # GET /users/<user>/props/
         property_backend.create(user=self.user1, key=propkey2, value=propval2)
 
         resp = self.get('/users/%s/props/' % username1)
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertDictEqual(self.parse(resp, 'dict'),
                              {propkey1: propval1, propkey2: propval2})
 
         resp = self.get('/users/%s/props/' % username2)
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertDictEqual(self.parse(resp, 'dict'), {})
 
     def test_get_multiple_properties(self):
@@ -408,12 +409,12 @@ class GetAllPropertiesTests(PropertyTests):  # GET /users/<user>/props/
         property_backend.create(user=self.user2, key=propkey3, value=propval3)
 
         resp = self.get('/users/%s/props/' % username1)
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertDictEqual(self.parse(resp, 'dict'),
                              {propkey1: propval1, propkey2: propval2})
 
         resp = self.get('/users/%s/props/' % username2)
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertDictEqual(self.parse(resp, 'dict'), {propkey3: propval3})
 
 
@@ -421,13 +422,13 @@ class CreatePropertyTests(PropertyTests):  # POST /users/<user>/props/
     def test_user_doesnt_exist(self):
         resp = self.post('/users/%s/props/' % username3,
                          {'prop': propkey1, 'value': propval1})
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
     def test_create_property(self):
         resp = self.post('/users/%s/props/' % username1,
                          {'prop': propkey1, 'value': propval1})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
 
         self.assertProperties(self.user1, {propkey1: propval1})
         self.assertProperties(self.user2, {})
@@ -435,7 +436,7 @@ class CreatePropertyTests(PropertyTests):  # POST /users/<user>/props/
         # we create a second property
         resp = self.post('/users/%s/props/' % username1,
                          {'prop': propkey2, 'value': propval2})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
 
         self.assertProperties(self.user1,
                              {propkey1: propval1, propkey2: propval2})
@@ -444,7 +445,7 @@ class CreatePropertyTests(PropertyTests):  # POST /users/<user>/props/
         # and a property for second user:
         resp = self.post('/users/%s/props/' % username2,
                          {'prop': propkey3, 'value': propval3})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertProperties(self.user1,
                              {propkey1: propval1, propkey2: propval2})
         self.assertProperties(self.user2, {propkey3: propval3})
@@ -454,7 +455,7 @@ class CreatePropertyTests(PropertyTests):  # POST /users/<user>/props/
 
         resp = self.post('/users/%s/props/' % username1,
                          {'prop': propkey1, 'value': propval2})
-        self.assertEqual(resp.status_code, httpclient.CONFLICT)
+        self.assertEqual(resp.status_code, http_client.CONFLICT)
 
         self.assertProperties(self.user1, {propkey1: propval1})
         self.assertProperties(self.user2, {})
@@ -462,24 +463,24 @@ class CreatePropertyTests(PropertyTests):  # POST /users/<user>/props/
     def test_create_invalid_property(self):
         resp = self.post('/users/%s/props/' % username1,
                          {'prop': "foo:bar", 'value': propval2})
-        self.assertEqual(resp.status_code, httpclient.PRECONDITION_FAILED)
+        self.assertEqual(resp.status_code, http_client.PRECONDITION_FAILED)
         self.assertProperties(self.user1, {})
 
     def test_bad_requests(self):
         resp = self.post('/users/%s/props/' % username2, {})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertProperties(self.user1, {})
         self.assertProperties(self.user2, {})
 
         resp = self.post('/users/%s/props/' % username2, {'foo': 'bar'})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertProperties(self.user1, {})
         self.assertProperties(self.user2, {})
 
         resp = self.post('/users/%s/props/' % username2, {
             'foo': 'bar', 'prop': propkey3, 'value': propval3
         })
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertProperties(self.user1, {})
         self.assertProperties(self.user2, {})
 
@@ -488,7 +489,7 @@ class SetMultiplePropertiesTests(PropertyTests):
     def test_user_doesnt_exist(self):
         resp = self.put('/users/%s/props/' % username3,
                         {propkey1: propval1, propkey2: propval2})
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
     def test_no_property(self):
@@ -550,24 +551,24 @@ class SetMultiplePropertiesTests(PropertyTests):
 class GetPropertyTests(PropertyTests):  # GET /users/<user>/props/<prop>/
     def test_user_doesnt_exist(self):
         resp = self.get('/users/%s/props/%s/' % (username3, propkey1))
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
     def test_property_doesnt_exist(self):
         resp = self.get('/users/%s/props/%s/' % (username1, propkey1))
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'property')
 
     def test_get_property(self):
         property_backend.create(user=self.user1, key=propkey1, value=propval1)
 
         resp = self.get('/users/%s/props/%s/' % (username1, propkey1))
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertEqual(self.parse(resp, 'str'), propval1)
 
         # check that user2 doesn't have it:
         resp = self.get('/users/%s/props/%s/' % (username2, propkey1))
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'property')
 
 
@@ -575,14 +576,14 @@ class SetPropertyTests(PropertyTests):  # PUT /users/<user>/props/<prop>/
     def test_user_doesnt_exist(self):
         resp = self.put(
             '/users/%s/props/%s/' % (username3, propkey1), {'value': propval1})
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
     def test_set_new_property(self):
         # set a property
         resp = self.put(
             '/users/%s/props/%s/' % (username1, propkey1), {'value': propval1})
-        self.assertEqual(resp.status_code, httpclient.CREATED)
+        self.assertEqual(resp.status_code, http_client.CREATED)
         self.assertEqual(property_backend.get(self.user1, propkey1), propval1)
         self.assertRaises(PropertyNotFound,
                           property_backend.get, self.user2, propkey1)
@@ -593,7 +594,7 @@ class SetPropertyTests(PropertyTests):  # PUT /users/<user>/props/<prop>/
         # set a property again and assert that it returns the old value:
         resp = self.put(
             '/users/%s/props/%s/' % (username1, propkey1), {'value': propval2})
-        self.assertEqual(resp.status_code, httpclient.OK)
+        self.assertEqual(resp.status_code, http_client.OK)
         self.assertEqual(self.parse(resp, 'str'), propval1)
         self.assertEqual(property_backend.get(self.user1, propkey1), propval2)
         self.assertRaises(PropertyNotFound,
@@ -602,29 +603,29 @@ class SetPropertyTests(PropertyTests):  # PUT /users/<user>/props/<prop>/
     def test_bad_request(self):
         # do some bad request tests:
         resp = self.put('/users/%s/props/%s/' % (username1, propkey1), {})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertProperties(self.user1, {})
 
         resp = self.put('/users/%s/props/%s/' % (username1, propkey1),
                         {'foo': 'bar'})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertProperties(self.user1, {})
 
         resp = self.put('/users/%s/props/%s/' % (username1, propkey1),
                         {'value': propkey3, 'foo': 'bar'})
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertProperties(self.user1, {})
 
 
 class DeletePropertyTests(PropertyTests):  # DELETE /users/<user>/props/<prop>/
     def test_user_doesnt_exist(self):
         resp = self.delete('/users/%s/props/%s/' % (username3, propkey1),)
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'user')
 
     def test_property_doesnt_exist(self):
         resp = self.delete('/users/%s/props/%s/' % (username1, propkey1),)
-        self.assertEqual(resp.status_code, httpclient.NOT_FOUND)
+        self.assertEqual(resp.status_code, http_client.NOT_FOUND)
         self.assertEqual(resp['Resource-Type'], 'property')
 
     def test_delete_property(self):
@@ -632,7 +633,7 @@ class DeletePropertyTests(PropertyTests):  # DELETE /users/<user>/props/<prop>/
         property_backend.create(user=self.user1, key=propkey2, value=propval2)
 
         resp = self.delete('/users/%s/props/%s/' % (username1, propkey1),)
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
         self.assertProperties(self.user1, {propkey2: propval2})
 
     def test_cross_user(self):
@@ -642,7 +643,7 @@ class DeletePropertyTests(PropertyTests):  # DELETE /users/<user>/props/<prop>/
         property_backend.create(user=self.user2, key=propkey1, value=propval1)
 
         resp = self.delete('/users/%s/props/%s/' % (username1, propkey1),)
-        self.assertEqual(resp.status_code, httpclient.NO_CONTENT)
+        self.assertEqual(resp.status_code, http_client.NO_CONTENT)
         self.assertProperties(self.user1, {})
         self.assertProperties(self.user2, {propkey1: propval1})
 
@@ -663,7 +664,7 @@ class HashTestMixin(RestAuthTestBase):
 
     @override_settings(MIN_PASSWORD_LENGTH=1)
     def test_testdata(self):
-        for password, data in self.testdata.items():
+        for password, data in six.iteritems(self.testdata):
             generated = make_password(password, data['salt'],
                                       hasher=self.algorithm)
             self.assertTrue(generated.startswith('%s$' % self.algorithm))
@@ -677,7 +678,7 @@ class HashTestMixin(RestAuthTestBase):
     @skipUnless(settings.USER_BACKEND == 'RestAuth.backends.django_backend.DjangoUserBackend', '')
     def test_backend(self):
         # test password during creation:
-        for password, data in self.testdata.items():
+        for password, data in six.iteritems(self.testdata):
             user = user_backend.create(username=username1,
                                        password=password,
                                        property_backend=property_backend)
@@ -687,7 +688,7 @@ class HashTestMixin(RestAuthTestBase):
             user_backend.remove(username=username1)
 
         # test password for set_password:
-        for password, data in self.testdata.items():
+        for password, data in six.iteritems(self.testdata):
             user = user_backend.create(username=username1,
                                        property_backend=property_backend)
             user_backend.set_password(username=username1, password=password)
