@@ -15,16 +15,13 @@
 # You should have received a copy of the GNU General Public License
 # along with RestAuth.  If not, see <http://www.gnu.org/licenses/>.
 
-try:
-    import httplib as httpclient  # python 2.x
-except ImportError:
-    from http import client as httpclient  # python 3.x
-
 from django.core.exceptions import ImproperlyConfigured
 from django.test.client import Client
 from django.test.client import RequestFactory
 from django.utils.unittest import TestCase
 
+from django.utils.six.moves import http_client
+
 from RestAuthCommon import handlers
 
 from RestAuth.Services.models import Service
@@ -62,14 +59,14 @@ class RestAuthMiddlewareTests(TestCase):
         request = self.factory.post('/users/', content, **self.extra)
         del request.META['CONTENT_TYPE']
         resp = self.mw.process_request(request)
-        self.assertEqual(resp.status_code, httpclient.UNSUPPORTED_MEDIA_TYPE)
+        self.assertEqual(resp.status_code, http_client.UNSUPPORTED_MEDIA_TYPE)
 
     def test_put_missing_content_type(self):
         content = self.handler.marshal_dict({'user': username1})
         request = self.factory.put('/users/', content, **self.extra)
         del request.META['CONTENT_TYPE']
         resp = self.mw.process_request(request)
-        self.assertEqual(resp.status_code, httpclient.UNSUPPORTED_MEDIA_TYPE)
+        self.assertEqual(resp.status_code, http_client.UNSUPPORTED_MEDIA_TYPE)
 
 
 class ContentTypeTests(RestAuthTest):
@@ -82,20 +79,20 @@ class ContentTypeTests(RestAuthTest):
         extra = self.extra
         del extra['content_type']
         resp = self.c.post('/users/', content, content_type='foo/bar', **extra)
-        self.assertEqual(resp.status_code, httpclient.UNSUPPORTED_MEDIA_TYPE)
+        self.assertEqual(resp.status_code, http_client.UNSUPPORTED_MEDIA_TYPE)
         self.assertItemsEqual(user_backend.list(), [])
 
     def test_wrong_accept_header(self):
         extra = self.extra
         extra['HTTP_ACCEPT'] = 'foo/bar'
         resp = self.c.get('/users/', **extra)
-        self.assertEqual(resp.status_code, httpclient.NOT_ACCEPTABLE)
+        self.assertEqual(resp.status_code, http_client.NOT_ACCEPTABLE)
         self.assertItemsEqual(user_backend.list(), [])
 
     def test_wrong_content(self):
         content = 'no_json_at_all}}}'
         resp = self.c.post('/users/', content, **self.extra)
-        self.assertEqual(resp.status_code, httpclient.BAD_REQUEST)
+        self.assertEqual(resp.status_code, http_client.BAD_REQUEST)
         self.assertItemsEqual(user_backend.list(), [])
 
 validators = (
@@ -133,7 +130,7 @@ class ValidatorTests(RestAuthTest):
         load_username_validators(validators)
 
         new_validators = get_validators()
-        self.assertEquals(len(validators) - substract, len(new_validators))
+        self.assertEqual(len(validators) - substract, len(new_validators))
         for val in new_validators:
             self.assertTrue(isinstance(val, Validator), type(val))
 
@@ -175,6 +172,7 @@ class BaseInstancetests(RestAuthTest):
         self.assertEqual(g.name, 'foobar')
         self.assertEqual(g.service, 'service')
 
+
 class BasicTests(RestAuthTest):
     def test_index(self):
         c = Client()
